/*
 * MZViewer - A viewer for MZData format Mass Spectra
 * Copyright (c) 2005 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package uk.ac.bbsrc.babraham.mzdata.displays;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;

import uk.ac.bbsrc.babraham.mzdata.MZViewer;

/**
 * @author andrewss
 *
 */
public class MZMenu extends JMenuBar {

    private MZViewer viewer;
    
    public MZMenu (MZViewer viewer) {
        
        this.viewer = viewer;
		MenuListener l = new MenuListener();

		JMenu fileMenu = new JMenu("File");
		JMenuItem fileOpen = new JMenuItem("Open...");
		fileOpen.setActionCommand("open");
		fileOpen.addActionListener(l);
		fileMenu.add(fileOpen);
		
		JMenuItem filePrint = new JMenuItem("Print...");
		filePrint.setActionCommand("print");
		filePrint.addActionListener(l);
		fileMenu.add(filePrint);
		
		
		JMenuItem fileExit = new JMenuItem("Exit");
		fileExit.setActionCommand("exit");
		fileExit.addActionListener(l);
		fileMenu.add(fileExit);
		add(fileMenu);
		
		JMenu helpMenu = new JMenu("Help");
		JMenuItem helpAbout = new JMenuItem("About...");
		helpAbout.setActionCommand("about");
		helpAbout.addActionListener(l);
		helpMenu.add(helpAbout);
        JMenuItem helpContents = new JMenuItem("Contents...");
        helpContents.setActionCommand("help");
        helpContents.addActionListener(l);
        helpMenu.add(helpContents);
		add(helpMenu);
    }
	public class MenuListener implements ActionListener {

		public void actionPerformed(ActionEvent ae) {
			String action = ae.getActionCommand();
			if (action.equals("open")){
				viewer.openNewFile();
			}
			
			else if (action.equals("print")) {
			    viewer.print();
			}
			
			else if (action.equals("exit")){
				System.exit(0);
			}
			else if (action.equals("about")){
				new AboutDialog(viewer);
			}
            else if (action.equals("help")){
                try {
                    new HelpDisplay();
                } 
                catch (IOException e) {
                    JOptionPane.showMessageDialog(viewer,"Error launching help: "+e.getMessage(),"Error",JOptionPane.ERROR_MESSAGE);
                    e.printStackTrace();
                }
            }

		}
		
	}
   
}
